@@ -1,10 +1,8 @@
 package PDL::Graphics2D;
 
-use strict;
-use warnings;
 use Exporter 'import'; # gives you Exporter's import() method directly
-our @EXPORT = qw(imag2d imag2d_update twiddle);     # symbols to export on request
-our @EXPORT_OK = qw(imag2d imag2d_update twiddle);  # symbols to export on request
+@EXPORT = qw(imag2d imag2d_update twiddle);     # symbols to export on request
+@EXPORT_OK = qw(imag2d imag2d_update twiddle);  # symbols to export on request
 
 =head1 NAME
 
@@ -196,7 +194,7 @@ sub mouse_click {
    # search for image corresponding to window
    foreach my $entry ( @imag2d_list ) {
       if ( $entry->{window_id} == $window_id ) {
-         $img = $entry->{img};  # 2D ndarray for now
+         $img = $entry->{img};  # 2D piddle for now
          last;
       }
    }
@@ -204,7 +202,7 @@ sub mouse_click {
    die "mouse_click: callback could not find image window\n" unless defined $img;
 
    # calculate zoom/aspect ratio factors
-   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistency
+   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistancy
 
    my $zoom_x = $width / $img->dim($glds+0);
    my $zoom_y = $height / $img->dim($glds+1);
@@ -251,7 +249,7 @@ sub resize_window {
    # search for image corresponding to window
    foreach my $entry ( @imag2d_list ) {
       if ( $entry->{window_id} == $window_id ) {
-         $img = $entry->{img};  # 2D ndarray for now
+         $img = $entry->{img};  # 2D piddle for now
          last;
       }
    }
@@ -259,7 +257,7 @@ sub resize_window {
    die "resize_window: callback could not find image window\n" unless defined $img;
 
    # calculate zoom/aspect ratio factors
-   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistency
+   my $glds = 0; $glds = 1 if $img->dim(0) < 5;  # hack, need verify consistancy
 
    my $zoom_x = $width / $img->dim($glds+0);
    my $zoom_y = $height / $img->dim($glds+1);
@@ -325,7 +323,7 @@ sub display_image {
    # search for image corresponding to window
    foreach my $entry ( @imag2d_list ) {
       if ( $entry->{window_id} == $window_id ) {
-         $img = $entry->{img};  # 2D ndarray for now
+         $img = $entry->{img};  # 2D piddle for now
          last;
       }
    }
@@ -401,7 +399,7 @@ sub ModeMenu {
       # search for image corresponding to window
       foreach my $listentry ( @imag2d_list ) {
          if ( $listentry->{window_id} == $window_id ) {
-            $img = $listentry->{img};  # 2D ndarray for now
+            $img = $listentry->{img};  # 2D piddle for now
             last;
          }
       }
@@ -593,7 +591,7 @@ sub display_new_window {
 };
 
 #------------------------------------------------------------------------
-# Display ndarray as 2-D image in window using OpenGL
+# Display piddle as 2-D image in window using OpenGL
 #------------------------------------------------------------------------
 
 =head1 FUNCTIONS
@@ -615,7 +613,7 @@ $c==4 the display is in GL_RGBA, for $c==3 the display is GL_RGB,
 for $c==2 the display is GL_LUMINANCE_ALPHA, and for $c==1 or for
 for dimensions ($M,$N) then the display is GL_LUMINANCE.
 
-This routine does not yet broadcast but multiple images may be
+This routine does not yet thread but multiple images may be
 viewed at the same time in separate windows by multiple
 calls to imag2d().  TriD graphics visualization windows and the
 imag2d() windows may be created and used independently.
@@ -628,12 +626,12 @@ the sub, only the imag2d() windows will update correctly.
 
   $window_id = imag2d($image, $name, $zoom, $x_off, $y_off);
     
-    creates a new image figure window from the input ndarray
+    creates a new image figure window from the input piddle
     with the given title, zoom factor, and position (if possible)
     
     $window_id - may be used to refer to the figure window
     
-    $image - 2D image ndarray with at least 2 or 3 dimensions
+    $image - 2D image piddle with at least 2 or 3 dimensions
              e.g. [M,N], [1,M,N], [2,M,N], [3,M,N], [4,M,N]
     
     $name - the name to use for the figure window (optional)
@@ -648,20 +646,20 @@ the sub, only the imag2d() windows will update correctly.
 
   use PDL::Graphics2D;     # imports imag2d() and twiddle()
 
-  $x = sequence(64,48,3);  # make test RGB image
-  $x = $x->mv(2,0);        # color must be dim(0) with size [0..4]
-  $x /= $x->max;           # pixel values in [0.0,1.0]
-  $x = sin(10*$x);
-  $w1 = imag2d($x);        # with parens...
-  $w2 = imag2d $x->sqrt;   # or without
-  $w3 = imag2d $x**2;
+  $a = sequence(64,48,3);  # make test RGB image
+  $a = $a->mv(2,0);        # color must be dim(0) with size [0..4]
+  $a /= $a->max;           # pixel values in [0.0,1.0]
+  $a = sin(10*$a);
+  $w1 = imag2d($a);        # with parens...
+  $w2 = imag2d $a->sqrt;   # or without
+  $w3 = imag2d $a**2;
 
 
 =head2 imag2d_update
 
 =for ref
 
-Update an existing imag2d window with new ndarray data
+Update an existing imag2d window with new piddle data
 
 =for usage
 
@@ -826,7 +824,7 @@ sub imag2d_update {
    # search for image corresponding to window
    foreach my $entry ( @imag2d_list ) {
       if ( $entry->{window_id} == $win_id ) {
-         $img = $entry->{img};  # 2D ndarray for now
+         $img = $entry->{img};  # 2D piddle for now
          last;
       }
    }
@@ -916,10 +914,10 @@ sub twiddle {
 }
 
 #------------------------------------------------------------------------
-# Broadcasted image display as tiles (code from PDL::Graphics::TriD::Image)
+# Threaded image display as tiles (code from PDL::Graphics::TriD::Image)
 #------------------------------------------------------------------------
 
-# N-D ndarray -> 2-D
+# N-D piddle -> 2-D
 sub flatten {
    my ($this,$bin_align) = @_;
 
@@ -977,6 +975,8 @@ sub flatten {
    my $firsty = 1;
    my $spi;
    for (@dims[reverse(2..$#dims)]) {
+      $foop->make_physdims();
+      # print "FOOP: \n"; $foop->dump;
       if ($ind % 2 == 0) {
          $spi = $foop->getdim(1)/$_;
          $foop = $foop->splitdim(1,$spi)->slice(":,0:-2")->mv(2,3);
